@@ -2,7 +2,7 @@ use crate::OutputFormat;
 use anyhow::{anyhow, Context as AnyhowContext, Result};
 use bytesize::ByteSize;
 use git_features::progress::{self, Progress};
-use git_object::{owned, Kind};
+use git_object::Kind;
 use git_odb::pack::{self, index};
 use std::{io, path::Path, str::FromStr};
 
@@ -63,7 +63,7 @@ impl Default for Context<Vec<u8>, Vec<u8>> {
         Context {
             output_statistics: None,
             thread_limit: None,
-            mode: index::verify::Mode::Sha1CRC32,
+            mode: index::verify::Mode::Sha1Crc32,
             algorithm: Algorithm::LessMemory,
             out: Vec::new(),
             err: Vec::new(),
@@ -74,7 +74,7 @@ impl Default for Context<Vec<u8>, Vec<u8>> {
 #[allow(clippy::large_enum_variant)]
 enum EitherCache {
     Left(pack::cache::Noop),
-    Right(pack::cache::LRU),
+    Right(pack::cache::Lru),
 }
 
 impl pack::cache::DecodeEntry for EitherCache {
@@ -104,7 +104,7 @@ pub fn pack_or_pack_index<W1, W2>(
         thread_limit,
         algorithm,
     }: Context<W1, W2>,
-) -> Result<(owned::Id, Option<index::traverse::Outcome>)>
+) -> Result<(git_hash::ObjectId, Option<index::traverse::Outcome>)>
 where
     W1: io::Write,
     W2: io::Write,
@@ -142,7 +142,7 @@ where
                     // turn off acceleration as we need to see entire chains all the time
                     EitherCache::Left(pack::cache::Noop)
                 } else {
-                    EitherCache::Right(pack::cache::LRU::default())
+                    EitherCache::Right(pack::cache::Lru::default())
                 }
             };
 
